==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/ZlecenieWyrobMedyczny.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.enums.RodzajZleceniaSrodekPom;
import pl.topteam.dps.enums.ZaopatrzeniePoSp;
import pl.topteam.dps.enums.ZlecenieSrodekPomDysfunkcja;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class ZlecenieWyrobMedyczny extends GenericDPSObject {
    /**
     * ZLECENIE_WYROB_MEDYCZNY.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * ZLECENIE_WYROB_MEDYCZNY.ADRES_OSOBY_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long adresOsobyId;

    /**
     * ZLECENIE_WYROB_MEDYCZNY.OSOBA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long osobaId;

    /**
     * ZLECENIE_WYROB_MEDYCZNY.ZLECENIE_NADRZEDNE_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long zlecenieNadrzedneId;

    /**
     * ZLECENIE_WYROB_MEDYCZNY.DATA_WYSTAWIENIA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataWystawienia;

    /**
     * ZLECENIE_WYROB_MEDYCZNY.DYSFUNKCJA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private ZlecenieSrodekPomDysfunkcja dysfunkcja;

    /**
     * ZLECENIE_WYROB_MEDYCZNY.ICD10
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String icd10;

    /**
     * ZLECENIE_WYROB_MEDYCZNY.NAZWA_DOKUMENTU
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String nazwaDokumentu;

    /**
     * ZLECENIE_WYROB_MEDYCZNY.NR_DOKUMENTU
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String nrDokumentu;

    /**
     * ZLECENIE_WYROB_MEDYCZNY.NR_EWIDENCYJNY
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String nrEwidencyjny;

    /**
     * ZLECENIE_WYROB_MEDYCZNY.RODZAJ
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private RodzajZleceniaSrodekPom rodzaj;

    /**
     * ZLECENIE_WYROB_MEDYCZNY.ZAOPATRZENIE_PO_SP
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private ZaopatrzeniePoSp zaopatrzeniePoSp;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return ZLECENIE_WYROB_MEDYCZNY.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * ZLECENIE_WYROB_MEDYCZNY.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return ZLECENIE_WYROB_MEDYCZNY.ADRES_OSOBY_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getAdresOsobyId() {
        return adresOsobyId;
    }

    /**
     * ZLECENIE_WYROB_MEDYCZNY.ADRES_OSOBY_ID
     *
     * @param adresOsobyId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setAdresOsobyId(Long adresOsobyId) {
        this.adresOsobyId = adresOsobyId;
    }

    /**
     * @return ZLECENIE_WYROB_MEDYCZNY.OSOBA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getOsobaId() {
        return osobaId;
    }

    /**
     * ZLECENIE_WYROB_MEDYCZNY.OSOBA_ID
     *
     * @param osobaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setOsobaId(Long osobaId) {
        this.osobaId = osobaId;
    }

    /**
     * @return ZLECENIE_WYROB_MEDYCZNY.ZLECENIE_NADRZEDNE_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getZlecenieNadrzedneId() {
        return zlecenieNadrzedneId;
    }

    /**
     * ZLECENIE_WYROB_MEDYCZNY.ZLECENIE_NADRZEDNE_ID
     *
     * @param zlecenieNadrzedneId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setZlecenieNadrzedneId(Long zlecenieNadrzedneId) {
        this.zlecenieNadrzedneId = zlecenieNadrzedneId;
    }

    /**
     * @return ZLECENIE_WYROB_MEDYCZNY.DATA_WYSTAWIENIA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataWystawienia() {
        return dataWystawienia;
    }

    /**
     * ZLECENIE_WYROB_MEDYCZNY.DATA_WYSTAWIENIA
     *
     * @param dataWystawienia
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataWystawienia(Date dataWystawienia) {
        this.dataWystawienia = dataWystawienia;
    }

    /**
     * @return ZLECENIE_WYROB_MEDYCZNY.DYSFUNKCJA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public ZlecenieSrodekPomDysfunkcja getDysfunkcja() {
        return dysfunkcja;
    }

    /**
     * ZLECENIE_WYROB_MEDYCZNY.DYSFUNKCJA
     *
     * @param dysfunkcja
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDysfunkcja(ZlecenieSrodekPomDysfunkcja dysfunkcja) {
        this.dysfunkcja = dysfunkcja;
    }

    /**
     * @return ZLECENIE_WYROB_MEDYCZNY.ICD10
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getIcd10() {
        return icd10;
    }

    /**
     * ZLECENIE_WYROB_MEDYCZNY.ICD10
     *
     * @param icd10
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setIcd10(String icd10) {
        this.icd10 = icd10 == null ? null : icd10.trim();
    }

    /**
     * @return ZLECENIE_WYROB_MEDYCZNY.NAZWA_DOKUMENTU
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getNazwaDokumentu() {
        return nazwaDokumentu;
    }

    /**
     * ZLECENIE_WYROB_MEDYCZNY.NAZWA_DOKUMENTU
     *
     * @param nazwaDokumentu
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setNazwaDokumentu(String nazwaDokumentu) {
        this.nazwaDokumentu = nazwaDokumentu == null ? null : nazwaDokumentu.trim();
    }

    /**
     * @return ZLECENIE_WYROB_MEDYCZNY.NR_DOKUMENTU
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getNrDokumentu() {
        return nrDokumentu;
    }

    /**
     * ZLECENIE_WYROB_MEDYCZNY.NR_DOKUMENTU
     *
     * @param nrDokumentu
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setNrDokumentu(String nrDokumentu) {
        this.nrDokumentu = nrDokumentu == null ? null : nrDokumentu.trim();
    }

    /**
     * @return ZLECENIE_WYROB_MEDYCZNY.NR_EWIDENCYJNY
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getNrEwidencyjny() {
        return nrEwidencyjny;
    }

    /**
     * ZLECENIE_WYROB_MEDYCZNY.NR_EWIDENCYJNY
     *
     * @param nrEwidencyjny
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setNrEwidencyjny(String nrEwidencyjny) {
        this.nrEwidencyjny = nrEwidencyjny == null ? null : nrEwidencyjny.trim();
    }

    /**
     * @return ZLECENIE_WYROB_MEDYCZNY.RODZAJ
     * @mbggenerated 2014-03-10 10:45:37
     */
    public RodzajZleceniaSrodekPom getRodzaj() {
        return rodzaj;
    }

    /**
     * ZLECENIE_WYROB_MEDYCZNY.RODZAJ
     *
     * @param rodzaj
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setRodzaj(RodzajZleceniaSrodekPom rodzaj) {
        this.rodzaj = rodzaj;
    }

    /**
     * @return ZLECENIE_WYROB_MEDYCZNY.ZAOPATRZENIE_PO_SP
     * @mbggenerated 2014-03-10 10:45:37
     */
    public ZaopatrzeniePoSp getZaopatrzeniePoSp() {
        return zaopatrzeniePoSp;
    }

    /**
     * ZLECENIE_WYROB_MEDYCZNY.ZAOPATRZENIE_PO_SP
     *
     * @param zaopatrzeniePoSp
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setZaopatrzeniePoSp(ZaopatrzeniePoSp zaopatrzeniePoSp) {
        this.zaopatrzeniePoSp = zaopatrzeniePoSp;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        ZlecenieWyrobMedyczny other = (ZlecenieWyrobMedyczny) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getAdresOsobyId() == null ? other.getAdresOsobyId() == null : this.getAdresOsobyId().equals(other.getAdresOsobyId()))
            && (this.getOsobaId() == null ? other.getOsobaId() == null : this.getOsobaId().equals(other.getOsobaId()))
            && (this.getZlecenieNadrzedneId() == null ? other.getZlecenieNadrzedneId() == null : this.getZlecenieNadrzedneId().equals(other.getZlecenieNadrzedneId()))
            && (this.getDataWystawienia() == null ? other.getDataWystawienia() == null : this.getDataWystawienia().equals(other.getDataWystawienia()))
            && (this.getDysfunkcja() == null ? other.getDysfunkcja() == null : this.getDysfunkcja().equals(other.getDysfunkcja()))
            && (this.getIcd10() == null ? other.getIcd10() == null : this.getIcd10().equals(other.getIcd10()))
            && (this.getNazwaDokumentu() == null ? other.getNazwaDokumentu() == null : this.getNazwaDokumentu().equals(other.getNazwaDokumentu()))
            && (this.getNrDokumentu() == null ? other.getNrDokumentu() == null : this.getNrDokumentu().equals(other.getNrDokumentu()))
            && (this.getNrEwidencyjny() == null ? other.getNrEwidencyjny() == null : this.getNrEwidencyjny().equals(other.getNrEwidencyjny()))
            && (this.getRodzaj() == null ? other.getRodzaj() == null : this.getRodzaj().equals(other.getRodzaj()))
            && (this.getZaopatrzeniePoSp() == null ? other.getZaopatrzeniePoSp() == null : this.getZaopatrzeniePoSp().equals(other.getZaopatrzeniePoSp()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getAdresOsobyId() == null) ? 0 : getAdresOsobyId().hashCode());
        result = prime * result + ((getOsobaId() == null) ? 0 : getOsobaId().hashCode());
        result = prime * result + ((getZlecenieNadrzedneId() == null) ? 0 : getZlecenieNadrzedneId().hashCode());
        result = prime * result + ((getDataWystawienia() == null) ? 0 : getDataWystawienia().hashCode());
        result = prime * result + ((getDysfunkcja() == null) ? 0 : getDysfunkcja().hashCode());
        result = prime * result + ((getIcd10() == null) ? 0 : getIcd10().hashCode());
        result = prime * result + ((getNazwaDokumentu() == null) ? 0 : getNazwaDokumentu().hashCode());
        result = prime * result + ((getNrDokumentu() == null) ? 0 : getNrDokumentu().hashCode());
        result = prime * result + ((getNrEwidencyjny() == null) ? 0 : getNrEwidencyjny().hashCode());
        result = prime * result + ((getRodzaj() == null) ? 0 : getRodzaj().hashCode());
        result = prime * result + ((getZaopatrzeniePoSp() == null) ? 0 : getZaopatrzeniePoSp().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", adresOsobyId=").append(adresOsobyId);
        sb.append(", osobaId=").append(osobaId);
        sb.append(", zlecenieNadrzedneId=").append(zlecenieNadrzedneId);
        sb.append(", dataWystawienia=").append(dataWystawienia);
        sb.append(", dysfunkcja=").append(dysfunkcja);
        sb.append(", icd10=").append(icd10);
        sb.append(", nazwaDokumentu=").append(nazwaDokumentu);
        sb.append(", nrDokumentu=").append(nrDokumentu);
        sb.append(", nrEwidencyjny=").append(nrEwidencyjny);
        sb.append(", rodzaj=").append(rodzaj);
        sb.append(", zaopatrzeniePoSp=").append(zaopatrzeniePoSp);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/ZlecenieWyrobMedyczny.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.enums.RodzajZleceniaSrodekPom;
import pl.topteam.dps.enums.ZaopatrzeniePoSp;
import pl.topteam.dps.enums.ZlecenieSrodekPomDysfunkcja;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class ZlecenieWyrobMedyczny extends GenericDPSObject {
    /**
     * ZLECENIE_WYROB_MEDYCZNY.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * ZLECENIE_WYROB_MEDYCZNY.ADRES_OSOBY_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long adresOsobyId;

    /**
     * ZLECENIE_WYROB_MEDYCZNY.OSOBA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long osobaId;

    /**
     * ZLECENIE_WYROB_MEDYCZNY.ZLECENIE_NADRZEDNE_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long zlecenieNadrzedneId;

    /**
     * ZLECENIE_WYROB_MEDYCZNY.DATA_WYSTAWIENIA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataWystawienia;

    /**
     * ZLECENIE_WYROB_MEDYCZNY.DYSFUNKCJA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private ZlecenieSrodekPomDysfunkcja dysfunkcja;

    /**
     * ZLECENIE_WYROB_MEDYCZNY.ICD10
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String icd10;

    /**
     * ZLECENIE_WYROB_MEDYCZNY.NAZWA_DOKUMENTU
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String nazwaDokumentu;

    /**
     * ZLECENIE_WYROB_MEDYCZNY.NR_DOKUMENTU
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String nrDokumentu;

    /**
     * ZLECENIE_WYROB_MEDYCZNY.NR_EWIDENCYJNY
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String nrEwidencyjny;

    /**
     * ZLECENIE_WYROB_MEDYCZNY.RODZAJ
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private RodzajZleceniaSrodekPom rodzaj;

    /**
     * ZLECENIE_WYROB_MEDYCZNY.ZAOPATRZENIE_PO_SP
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private ZaopatrzeniePoSp zaopatrzeniePoSp;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return ZLECENIE_WYROB_MEDYCZNY.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * ZLECENIE_WYROB_MEDYCZNY.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return ZLECENIE_WYROB_MEDYCZNY.ADRES_OSOBY_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getAdresOsobyId() {
        return adresOsobyId;
    }

    /**
     * ZLECENIE_WYROB_MEDYCZNY.ADRES_OSOBY_ID
     *
     * @param adresOsobyId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setAdresOsobyId(Long adresOsobyId) {
        this.adresOsobyId = adresOsobyId;
    }

    /**
     * @return ZLECENIE_WYROB_MEDYCZNY.OSOBA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getOsobaId() {
        return osobaId;
    }

    /**
     * ZLECENIE_WYROB_MEDYCZNY.OSOBA_ID
     *
     * @param osobaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setOsobaId(Long osobaId) {
        this.osobaId = osobaId;
    }

    /**
     * @return ZLECENIE_WYROB_MEDYCZNY.ZLECENIE_NADRZEDNE_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getZlecenieNadrzedneId() {
        return zlecenieNadrzedneId;
    }

    /**
     * ZLECENIE_WYROB_MEDYCZNY.ZLECENIE_NADRZEDNE_ID
     *
     * @param zlecenieNadrzedneId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setZlecenieNadrzedneId(Long zlecenieNadrzedneId) {
        this.zlecenieNadrzedneId = zlecenieNadrzedneId;
    }

    /**
     * @return ZLECENIE_WYROB_MEDYCZNY.DATA_WYSTAWIENIA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataWystawienia() {
        return dataWystawienia;
    }

    /**
     * ZLECENIE_WYROB_MEDYCZNY.DATA_WYSTAWIENIA
     *
     * @param dataWystawienia
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataWystawienia(Date dataWystawienia) {
        this.dataWystawienia = dataWystawienia;
    }

    /**
     * @return ZLECENIE_WYROB_MEDYCZNY.DYSFUNKCJA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public ZlecenieSrodekPomDysfunkcja getDysfunkcja() {
        return dysfunkcja;
    }

    /**
     * ZLECENIE_WYROB_MEDYCZNY.DYSFUNKCJA
     *
     * @param dysfunkcja
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDysfunkcja(ZlecenieSrodekPomDysfunkcja dysfunkcja) {
        this.dysfunkcja = dysfunkcja;
    }

    /**
     * @return ZLECENIE_WYROB_MEDYCZNY.ICD10
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getIcd10() {
        return icd10;
    }

    /**
     * ZLECENIE_WYROB_MEDYCZNY.ICD10
     *
     * @param icd10
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setIcd10(String icd10) {
        this.icd10 = icd10 == null ? null : icd10.trim();
    }

    /**
     * @return ZLECENIE_WYROB_MEDYCZNY.NAZWA_DOKUMENTU
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getNazwaDokumentu() {
        return nazwaDokumentu;
    }

    /**
     * ZLECENIE_WYROB_MEDYCZNY.NAZWA_DOKUMENTU
     *
     * @param nazwaDokumentu
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setNazwaDokumentu(String nazwaDokumentu) {
        this.nazwaDokumentu = nazwaDokumentu == null ? null : nazwaDokumentu.trim();
    }

    /**
     * @return ZLECENIE_WYROB_MEDYCZNY.NR_DOKUMENTU
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getNrDokumentu() {
        return nrDokumentu;
    }

    /**
     * ZLECENIE_WYROB_MEDYCZNY.NR_DOKUMENTU
     *
     * @param nrDokumentu
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setNrDokumentu(String nrDokumentu) {
        this.nrDokumentu = nrDokumentu == null ? null : nrDokumentu.trim();
    }

    /**
     * @return ZLECENIE_WYROB_MEDYCZNY.NR_EWIDENCYJNY
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getNrEwidencyjny() {
        return nrEwidencyjny;
    }

    /**
     * ZLECENIE_WYROB_MEDYCZNY.NR_EWIDENCYJNY
     *
     * @param nrEwidencyjny
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setNrEwidencyjny(String nrEwidencyjny) {
        this.nrEwidencyjny = nrEwidencyjny == null ? null : nrEwidencyjny.trim();
    }

    /**
     * @return ZLECENIE_WYROB_MEDYCZNY.RODZAJ
     * @mbggenerated 2014-03-13 16:02:38
     */
    public RodzajZleceniaSrodekPom getRodzaj() {
        return rodzaj;
    }

    /**
     * ZLECENIE_WYROB_MEDYCZNY.RODZAJ
     *
     * @param rodzaj
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setRodzaj(RodzajZleceniaSrodekPom rodzaj) {
        this.rodzaj = rodzaj;
    }

    /**
     * @return ZLECENIE_WYROB_MEDYCZNY.ZAOPATRZENIE_PO_SP
     * @mbggenerated 2014-03-13 16:02:38
     */
    public ZaopatrzeniePoSp getZaopatrzeniePoSp() {
        return zaopatrzeniePoSp;
    }

    /**
     * ZLECENIE_WYROB_MEDYCZNY.ZAOPATRZENIE_PO_SP
     *
     * @param zaopatrzeniePoSp
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setZaopatrzeniePoSp(ZaopatrzeniePoSp zaopatrzeniePoSp) {
        this.zaopatrzeniePoSp = zaopatrzeniePoSp;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        ZlecenieWyrobMedyczny other = (ZlecenieWyrobMedyczny) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getAdresOsobyId() == null ? other.getAdresOsobyId() == null : this.getAdresOsobyId().equals(other.getAdresOsobyId()))
            && (this.getOsobaId() == null ? other.getOsobaId() == null : this.getOsobaId().equals(other.getOsobaId()))
            && (this.getZlecenieNadrzedneId() == null ? other.getZlecenieNadrzedneId() == null : this.getZlecenieNadrzedneId().equals(other.getZlecenieNadrzedneId()))
            && (this.getDataWystawienia() == null ? other.getDataWystawienia() == null : this.getDataWystawienia().equals(other.getDataWystawienia()))
            && (this.getDysfunkcja() == null ? other.getDysfunkcja() == null : this.getDysfunkcja().equals(other.getDysfunkcja()))
            && (this.getIcd10() == null ? other.getIcd10() == null : this.getIcd10().equals(other.getIcd10()))
            && (this.getNazwaDokumentu() == null ? other.getNazwaDokumentu() == null : this.getNazwaDokumentu().equals(other.getNazwaDokumentu()))
            && (this.getNrDokumentu() == null ? other.getNrDokumentu() == null : this.getNrDokumentu().equals(other.getNrDokumentu()))
            && (this.getNrEwidencyjny() == null ? other.getNrEwidencyjny() == null : this.getNrEwidencyjny().equals(other.getNrEwidencyjny()))
            && (this.getRodzaj() == null ? other.getRodzaj() == null : this.getRodzaj().equals(other.getRodzaj()))
            && (this.getZaopatrzeniePoSp() == null ? other.getZaopatrzeniePoSp() == null : this.getZaopatrzeniePoSp().equals(other.getZaopatrzeniePoSp()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getAdresOsobyId() == null) ? 0 : getAdresOsobyId().hashCode());
        result = prime * result + ((getOsobaId() == null) ? 0 : getOsobaId().hashCode());
        result = prime * result + ((getZlecenieNadrzedneId() == null) ? 0 : getZlecenieNadrzedneId().hashCode());
        result = prime * result + ((getDataWystawienia() == null) ? 0 : getDataWystawienia().hashCode());
        result = prime * result + ((getDysfunkcja() == null) ? 0 : getDysfunkcja().hashCode());
        result = prime * result + ((getIcd10() == null) ? 0 : getIcd10().hashCode());
        result = prime * result + ((getNazwaDokumentu() == null) ? 0 : getNazwaDokumentu().hashCode());
        result = prime * result + ((getNrDokumentu() == null) ? 0 : getNrDokumentu().hashCode());
        result = prime * result + ((getNrEwidencyjny() == null) ? 0 : getNrEwidencyjny().hashCode());
        result = prime * result + ((getRodzaj() == null) ? 0 : getRodzaj().hashCode());
        result = prime * result + ((getZaopatrzeniePoSp() == null) ? 0 : getZaopatrzeniePoSp().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", adresOsobyId=").append(adresOsobyId);
        sb.append(", osobaId=").append(osobaId);
        sb.append(", zlecenieNadrzedneId=").append(zlecenieNadrzedneId);
        sb.append(", dataWystawienia=").append(dataWystawienia);
        sb.append(", dysfunkcja=").append(dysfunkcja);
        sb.append(", icd10=").append(icd10);
        sb.append(", nazwaDokumentu=").append(nazwaDokumentu);
        sb.append(", nrDokumentu=").append(nrDokumentu);
        sb.append(", nrEwidencyjny=").append(nrEwidencyjny);
        sb.append(", rodzaj=").append(rodzaj);
        sb.append(", zaopatrzeniePoSp=").append(zaopatrzeniePoSp);
        sb.append("]");
        return sb.toString();
    }
}
